import { RouterView } from 'vue-router';

export default {
    path: '/account',
    name: 'Account',
    meta: {
        title: 'users',
        icon: 'face',
        moduleName: 'Account',
    },
    component: RouterView,
    redirect: { name: 'AccountMain' },
    menus: {
        main: [
            'AccountList',
            'AccountAliasList',
            'AccountRoles',
            'AccountAccounts',
            'AccountLdap',
            'AccountSamba',
            'AccountAcls',
            'AccountConnections',
        ],
        card: [],
    },
    children: [
        {
            path: '',
            name: 'AccountMain',
            component: () => import('src/pages/Account/AccountMain.vue'),
            redirect: { name: 'AccountList' },
            children: [
                {
                    path: 'list',
                    name: 'AccountList',
                    meta: {
                        title: 'list',
                        icon: 'view_list',
                    },
                    component: () => import('src/pages/Account/AccountList.vue'),
                },
                {
                    path: 'role-list',
                    name: 'AccountRoles',
                    meta: {
                        title: 'roles',
                        icon: 'group',
                    },
                    component: () => import('src/pages/Account/Role/AccountRoles.vue'),
                },
                {
                    path: 'alias-list',
                    name: 'AccountAliasList',
                    meta: {
                        title: 'alias',
                        icon: 'email',
                    },
                    component: () => import('src/pages/Account/AccountAliasList.vue'),
                },
                {
                    path: 'connections',
                    name: 'AccountConnections',
                    meta: {
                        title: 'connections',
                        icon: 'check',
                    },
                    component: () => import('src/pages/Account/AccountConnections.vue'),
                },
                {
                    path: 'accounts',
                    name: 'AccountAccounts',
                    meta: {
                        title: 'accounts',
                        icon: 'accessibility',
                        roles: ['itManagement'],
                    },
                    component: () => import('src/pages/Account/AccountAccounts.vue'),
                },
                {
                    path: 'ldap',
                    name: 'AccountLdap',
                    meta: {
                        title: 'ldap',
                        icon: 'account_tree',
                        roles: ['itManagement'],
                    },
                    component: () => import('src/pages/Account/AccountLdap.vue'),
                },
                {
                    path: 'samba',
                    name: 'AccountSamba',
                    meta: {
                        title: 'samba',
                        icon: 'preview',
                        roles: ['itManagement'],
                    },
                    component: () => import('src/pages/Account/AccountSamba.vue'),
                },
                {
                    path: 'acls',
                    name: 'AccountAcls',
                    meta: {
                        title: 'acls',
                        icon: 'check',
                    },
                    component: () => import('src/pages/Account/AccountAcls.vue'),
                },
                {
                    path: 'acl-form',
                    name: 'AccountAclForm',
                    component: () => import('src/pages/Account/Acls/AclFormView.vue'),
                },
            ],
        },
    ],
};
