import { vi, describe, expect, it, beforeEach, beforeAll } from 'vitest';
import useRedirect from 'src/composables/useRedirect';
import { useRouter } from 'vue-router';

vi.mock('vue-router');

describe('useRedirect', () => {
    useRouter.mockReturnValue({
        push: vi.fn(),
        currentRoute: {
            value: {
                matched: [
                    { path: '/' },
                    { path: '/customer' },
                    { path: '/customer/:id' },
                    { path: '/customer/:id/basic-data' },
                ],
            },
        },
    });
    const data = [];
    let navigate;
    let spy;

    beforeAll(() => {
        const { navigate: navigateFn } = useRedirect();
        navigate = navigateFn;
        spy = useRouter().push;
    });

    beforeEach(() => {
        data.length = 0;
        spy.mockReset();
    });

    it('should redirect to list page if there are several results', async () => {
        data.push({ id: 1, name: 'employee' }, { id: 2, name: 'boss' });
        navigate(data, {});
        expect(spy).toHaveBeenCalledWith({ path: '/customer/' });
    });

    it('should redirect to list page if there is no results', async () => {
        navigate(data, {});
        expect(spy).toHaveBeenCalledWith({ path: '/customer/' });
    });

    it('should redirect to basic-data page if there is only one result', async () => {
        data.push({ id: 1, name: 'employee' });
        navigate(data, {});
        expect(spy).toHaveBeenCalledWith({ path: '/customer/1/basic-data' });
    });
});
